==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/modelio/MDLAreaLight.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.modelio;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coregraphics.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("ModelIO") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/MDLAreaLight/*</name>*/ 
    extends /*<extends>*/MDLPhysicallyPlausibleLight/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class MDLAreaLightPtr extends Ptr<MDLAreaLight, MDLAreaLightPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(MDLAreaLight.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public MDLAreaLight() {}
    protected MDLAreaLight(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "areaRadius")
    public native float getAreaRadius();
    @Property(selector = "setAreaRadius:")
    public native void setAreaRadius(float v);
    @Property(selector = "superEllipticPower")
    public native VectorFloat2 getSuperEllipticPower();
    @Property(selector = "setSuperEllipticPower:")
    public native void setSuperEllipticPower(VectorFloat2 v);
    @Property(selector = "aspect")
    public native float getAspect();
    @Property(selector = "setAspect:")
    public native void setAspect(float v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/modelio/MDLAreaLight.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.modelio;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coregraphics.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 9.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("ModelIO") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/MDLAreaLight/*</name>*/ 
    extends /*<extends>*/MDLPhysicallyPlausibleLight/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class MDLAreaLightPtr extends Ptr<MDLAreaLight, MDLAreaLightPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(MDLAreaLight.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public MDLAreaLight() {}
    protected MDLAreaLight(Handle h, long handle) { super(h, handle); }
    protected MDLAreaLight(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "areaRadius")
    public native float getAreaRadius();
    @Property(selector = "setAreaRadius:")
    public native void setAreaRadius(float v);
    @Property(selector = "superEllipticPower")
    public native @ByVal VectorFloat2 getSuperEllipticPower();
    @Property(selector = "setSuperEllipticPower:")
    public native void setSuperEllipticPower(@ByVal VectorFloat2 v);
    @Property(selector = "aspect")
    public native float getAspect();
    @Property(selector = "setAspect:")
    public native void setAspect(float v);
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    
    /*</methods>*/
}
